<?php
/*
 * This file contains various common function for the jupload plugin
 */

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}

$juploadRootDirectory = 'plugins/jupload/';
 
//####################################################################################################
//##############################  PARAMETER DEFINITION ###############################################
//####################################################################################################

//These texts will be both displayed on the screen, and written in the configuration file.
//See also the jupload/page/config_page.php file

/*
 * $JUploadParamList is an array of param. Each param contains the following keys:
 * name: the parameter name. It's the key that'll be stored in the $JUPLOAD_CONFIG array.
 * desc: an explanation about the parameter. Only in english. This explanation will only be visible to admins.
 * default: The default value for this parameter.
 * type: the data type for this parameter. Can be 'int' or 'string'. Any unknown value is managed as a string.
 */

$JUploadParamList = array 
(
array (
	'name' => 'alwaysVisible',
	'desc' => <<<EOS
<B>Caution: Signification changed (a little) since v2.4.1</B><BR>
<DIR>
 <LI><U>If set to 0</U>, the JUpload link will only be displayed if the user may upload pictures
 <LI><U>If set to 1</U>, the JUpload link will always be visible, whenever the user may or may not upload pictures.<BR> 
 If the user clicks on it, here is what happens:<BR>
 <DIR>
  <LI>a- If the user may upload pictures, the upload page containing the applet opens,
  <LI>b- If the user is authenticated, but may not upload pictures, an error message is displayed,
  <LI>c- If the user is not authenticated, an error page containing a link to the login page is displayed. Once 
  connected, the user is redirected to the upload page. We go back to step 1, above.
 </DIR>
 <LI><U>If set to 2</U>, the JUpload link will only be displayed if the user is connected and is an administrator 
 of the gallery. 
</DIR>
Other values than 0, 1 or 2 are treated as the default value.
EOS
,
	'default' => '0',
	'type' => 'int'
	)
,
array (
	'name' => 'basicHttpAuthentication',
	'desc' => <<<EOS
This parameter allows use of basic HTTP authentication in the applet. This authentication can be triggered 
through the .htaccess. See the AuthUserFile, AuthName, AuthType and require. <BR>
Note: To use the <I>basicHttpAuthentication</I> parameter, then <I>AuthType</I> must contain <I>Basic</I>.
<BR>
The format for this parameter is <B><I>user:password</I></B>
<BR>
If empty (default value), this parameter is ignored (no authentication).
EOS
,
	'default' => '',
	'type' => 'string'
	)
,
array (
	'name' => 'generateDefaultPictureTitle',
	'desc' => <<<EOS
If set to a non 0 value (1 is the default value), the plugin will define a default title for each picture, based on the filename. All
underscores are removed. For instance, when uploading a <I>When_I_m_Happy.jpg</I> file, it will create a default
title <I>When I m Happy</I>.
<BR>
If 1, the picture title is left blank.  
EOS
	,
	'default' => '1',
	'type' => 'int'
	)
,
array (
	'name' => 'highQualityPreview',
	'desc' => <<<EOS
If set to a non 0 value, the JUpload will display better preview icons. But pictures will then display slower 
within the applet. This parameter applies when resizing the picture. Setting it to 1 creates smoother resized 
pictures It is different from the pictureCompressionQuality, that controls the jpeg compression of the files itself.
<BR>
The pictures sent to the server are always of the best available quality, whatever is the value of this parameter.<BR>
EOS
	,
	'default' => '1',
	'type' => 'int'
	)
,
array (
	'name' => 'jarPath',
	'desc' => <<<EOS
This parameter contains the path where the navigator should find the wjhk.jupload.jar file. This jar file contains 
the JUpload applet, and is absolutely necessary for this plugin.<BR>
It should contain one of the following values, in this order of priority:
 <DIR>
  <LI>Standard case: let this parameter empty. The default value is correct for standard Coppermine configuration.
  <LI>The absolute path of the jar file, ending with a slash, when your installation is not a standard 
  Coppermine installation. For instance, when Coppermine is itself a plugin of another tool.
  For instance: <I>/coppermine/plugins/jupload/</I>
  <LI>The relative path from the page calling the applet. Ending 
 </DIR> 
EOS
	,
	'default' => 'plugins/jupload/',
	'type' => 'string'
	)
,
array (
	'name' => 'linkComment',
	'desc' => <<<EOS
This parameter allows the admin to override the translated value of JUpload comment. This is the explanation text 
that is displayed when the mouse is over the JUpload button.<BR>
Take care that, if set, this text will be displayed whatever the user language is.<BR>
When this string is empty, the translated value is used. 
EOS
	,
	'default' => '',
	'type' => 'string'
	)
,
array (
	'name' => 'linkKeepStandardUpload',
	'desc' => <<<EOS
Indicates whether you want to keep the upload form, coming with Coppermine, or not. 0 indicates that the standard
upload link should disappear from the menu. 1 means that the two upload links are visible.  
EOS
	,
	'default' => '1',
	'type' => 'int'
	)
,
array (
	'name' => 'linkTitle',
	'desc' => <<<EOS
This parameter allows the admin to override the translated value of JUpload title. This is the text that is 
displayed on the JUpload button.<BR>
Take care that, if set, this text will be displayed whatever the user language is.<BR>
When this string is empty, the translated value is used. 
EOS
	,
	'default' => '',
	'type' => 'string'
	)
,
array (
	'name' => 'maxChunkSize',
	'desc' => <<<EOS
This value is the number of Kb that your webserver will allow for an upload. It may be smaller than the maximum
file size that you allow on your gallery.<BR>
<I>maxChunkSize</I> is a technical parameter, that allows you to override your webserver technical limitation
in upload file size.<BR>
Default is -1, meaning: no chunk. <BR>
If you know the maximum upload size of your webserver (or ISP), put it here. This limitation is often 2Mb (default
value in PHP configuration). Otherwise, let it empty.<BR>
Note: this value can be smaller than the effective server limitation. 
EOS
	,
	'default' => '-1',
	'type' => 'int'
	)
,
array (
	'name' => 'maxFileSize',
	'desc' => <<<EOS
This value is the maximum length of file, in kb, that you allow on your gallery, when uploading with JUpload. 
Default is the maximum file length defined in the Coppermine configuration. <BR>
You can put here a bigger value, than your Coppermine configuration max file, as this one must not be bigger than
the maximum upload size of your server. <BR>
If you put here a bigger value than the maximum upload size of your server, you should define a value for 
<I>maxChunkSize</I>.    <BR>
<U>Note:</U> When the upload is done in chunk mode, Coppermine internal code controls the size of the last upload, 
that is : the size of the last chunk, and not the size of the whole uploaded file, that may have been split into 
several chunk. 

EOS
	,
	'default' => (isset($CONFIG)) ? $CONFIG['max_upl_size'] : -1, //$CONFIG is not set, when called from ./plugins/jupload/configuration.php	
	'type' => 'int'
	)
,
array (
	'name' => 'maxNonTransformedPictureSize',
	'desc' => <<<EOS
This parameter is important to control to define who of the applet or the server resizes pictures biggers than the 
maximum picture size (in pixels) that you have defined in your Coppermine configuration. This is <U>important as the 
applet will resize pictures much slower than the GD (or ImageMagik) library on your server</U>. But, if the applet
resizes the picture, it will do it before upload. The upload is then much quicker, as the file to transmit will
probably be much smaller than your original picture file (4Mb to 400kb in my case).  
<BR>
This parameters applies only on pictures that the applet does not need to transform (that is: non rotated pictures).
In this case, the applet will resize or not the picture, depending on this parameter.
<BR>
To sum up:
<DIR>
<LI>if you put a value in this field:
	<DIR>
		<LI>Pictures that the user does not modify are resized or not, depending on this parameter.
		<LI>Pictures that the user modifies (picture rotation for instance) are transformed before upload, 
		and the tranformed picture file is automatically resized according to the current Coppermine configuration.
	</DIR>
<LI>if you do not put a value in this field, all pictures are resized, before upload, according to the 
Coppermine maxPictureSize.
</DIR>
<BR>If you put a 'big' value in this field. The consequence is:
<DIR>
	<LI>If the picture to upload is bigger than the Coppermine maxPictureSize
		<DIR>
		<LI>CPU time is much smaller, as Java is not really quick in picture work.
		<LI>Network traffic is bigger, as your original picture is sent to the server (instead of the resized picture) 
		</DIR>
	<LI>If the picture is less or equal to the Coppermine maxPictureSize
		<DIR>
		<LI>No change wether you use this parameter or not: there is no work to do on pictures to add them to
		your gallery. 
		</DIR>
</DIR>
<B>Be careful</B> that, if you put a big value here, you may encounter limitation with your server maxUploadSize.
You should take a look to the maxChunkSize and maxFileSize parameters.
The default behaviour is to provide the Coppermine maxPictureSize to the applet.   
EOS
	,
	'default' => -1,
	'type' => 'int'
	)
,
array (
	'name' => 'pictureCompressionQuality',
	'desc' => <<<EOS
This value represents the quality compression, for jpeg picture files. Bigger quality means higher quality
and bigger file. The default value corresponds to the Coppermine compression quality. 
EOS
	,
	'default' => '0.8',
	'type' => 'float'
	)
);

 

//####################################################################################################
//#################################    FUNCTIONS    ##################################################
//####################################################################################################


//####################################################################################################
//##############################     LOCAL CODE     ##################################################
//####################################################################################################

//Localisation. Handled from specific files, to make upgrade of coppermine easier:
//First: we load the default text (english)
require($juploadRootDirectory . 'lang/english.php');

//Then, you overload with the choosen language, for existing translations.
//$bJuploadTranslactionExist is used later, in page_upload.php, to display a message indicating that
//the translation for the current language doesn't exist ... and to give the link to the page where all
//the text to translate is written (part of text is in the applet, not in the php code).

//$CONFIG is not set, when called from ./plugins/jupload/configuration.php
$defaultLang = (isset($CONFIG)) ? $CONFIG['lang'] : '';
if (isset($USER['lang'])) {
	$defaultLang = $USER['lang'];
}
$defaultLangFile = $juploadRootDirectory . 'lang/' . $defaultLang . '.php';


$bJuploadTranslactionExist = file_exists($defaultLangFile);

if ($defaultLang == 'english'  ||  $defaultLang == 'english_gb') {
	//We already included (required) the jupload english.php file
	$bJuploadTranslactionExist = true;  //Was not true for english_gb, one line before ...   ;-)
} else if ($bJuploadTranslactionExist) {
    include($defaultLangFile);
}
//Let's call any user specific constant, like overriding of the 'standard' translation texts.
$user_inc = $juploadRootDirectory . 'user/user.inc.php';
if (file_exists($user_inc)) { 
	require($user_inc);
}


/////////////////////////////////////////////////////////////////////////////////////////////////
//Let's load the config file, or use default values, for non defined variables.
$config_inc = $juploadRootDirectory . 'user/config.inc.php';
if (file_exists($config_inc)) { 
	require($config_inc);
}
foreach($JUploadParamList as $param) {
	if (!isset($JUPLOAD_CONFIG[$param['name']])) {
		$JUPLOAD_CONFIG[$param['name']] = $param['default'];
	}
}//foreach($JUploadParamList)

//Specific test for some parameter
if ($JUPLOAD_CONFIG['alwaysVisible'] != 0 
&& $JUPLOAD_CONFIG['alwaysVisible'] != 1 
&& $JUPLOAD_CONFIG['alwaysVisible'] != 2) {
	$JUPLOAD_CONFIG['alwaysVisible'] = 0;
}

//Let's create a 'default' version number, for my internal tests
$JUPLOAD_CONFIG['version']='not packaged'; 
//This internal version number should be replaced by the next line, added during packaging
//Ok, this could be better. But it works, that's a point !    ;-)
$JUPLOAD_CONFIG['version']='2.5.7'; 
